==> signature_ps-0.23.0.crate: signature_ps-0.23.0/CHANGELOG.md <==
# Changelog

All notable changes to this crate will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.23.0 - 2021-10-04
### Changed
- Dependencies updated

## v0.22.0 - 2021-09-27
### Changed
- Ockam compiles under no_std + alloc.
- Dependencies updated

## v0.21.0 - 2021-09-20
### Changed
- Dependencies updated

## v0.20.0 - 2021-09-14
### Changed
- Fixed incorrect link in README

## v0.19.0 - 2021-09-13
### Changed
- Dependencies updated.

## v0.18.0 - 2021-09-03
### Changed
- Dependencies updated.

## v0.17.0 - 2021-08-30
### Changed
- Dependencies updated.

## v0.16.0 - 2021-08-23
### Changed
- Replace std:: modules with core:: and alternate implementations
- Dependencies updated.

## v0.15.0 - 2021-08-16
### Changed
- Dependencies updated.

## v0.14.0 - 2021-08-09
### Changed
- Dependencies updated.

## v0.13.0 - 2021-08-03
### Changed
- Dependencies updated.

## v0.12.0 - 2021-07-29
### Changed
- Dependencies updated.

## v0.11.0 - 2021-07-26
### Added
- Add threshold BLS signing.
### Changed
- Dependencies updated.

## v0.10.0 - 2021-07-19
### Changed
- Dependencies updated.

## v0.9.0 - 2021-07-12
### Changed
- Dependencies updated.

## v0.8.0 - 2021-07-06
### Changed
- Dependencies updated.

## v0.7.0 - 2021-06-30
### Changed
- Fix clippy warnings.
- Dependencies updated.

## v0.6.0 - 2021-06-21
### Changed
- Dependencies updated.

## v0.5.0 - 2021-06-14
### Changed
- Fixed key size of PS key.
- Dependencies updated.

## v0.3.0 - 2021-05-17
### Added
### Changed
- Dependencies updated.
### Deleted

## v0.2.0 - 2021-05-10
### Added
### Changed
- Dependencies updated.
- Documentation edits.

### Deleted

## v0.1.1 - 2021-05-03
### Changes
- Fixed crate metadata and documentation.

## v0.1.0 - 2021-04-26
- Initial release.

==> signature_ps-0.26.0.crate: signature_ps-0.26.0/CHANGELOG.md <==
# Changelog

All notable changes to this crate will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.26.0 - 2021-10-25
### Changed
- Move as many things as possible into a workspace.
- Dependencies updated

## v0.25.0 - 2021-10-18
### Changed
- Dependencies updated

## v0.24.0 - 2021-10-11
### Changed
- Dependencies updated

## v0.23.0 - 2021-10-04
### Changed
- Dependencies updated

## v0.22.0 - 2021-09-27
### Changed
- Ockam compiles under no_std + alloc.
- Dependencies updated

## v0.21.0 - 2021-09-20
### Changed
- Dependencies updated

## v0.20.0 - 2021-09-14
### Changed
- Fixed incorrect link in README

## v0.19.0 - 2021-09-13
### Changed
- Dependencies updated.

## v0.18.0 - 2021-09-03
### Changed
- Dependencies updated.

## v0.17.0 - 2021-08-30
### Changed
- Dependencies updated.

## v0.16.0 - 2021-08-23
### Changed
- Replace std:: modules with core:: and alternate implementations
- Dependencies updated.

## v0.15.0 - 2021-08-16
### Changed
- Dependencies updated.

## v0.14.0 - 2021-08-09
### Changed
- Dependencies updated.

## v0.13.0 - 2021-08-03
### Changed
- Dependencies updated.

## v0.12.0 - 2021-07-29
### Changed
- Dependencies updated.

## v0.11.0 - 2021-07-26
### Added
- Add threshold BLS signing.
### Changed
- Dependencies updated.

## v0.10.0 - 2021-07-19
### Changed
- Dependencies updated.

## v0.9.0 - 2021-07-12
### Changed
- Dependencies updated.

## v0.8.0 - 2021-07-06
### Changed
- Dependencies updated.

## v0.7.0 - 2021-06-30
### Changed
- Fix clippy warnings.
- Dependencies updated.

## v0.6.0 - 2021-06-21
### Changed
- Dependencies updated.

## v0.5.0 - 2021-06-14
### Changed
- Fixed key size of PS key.
- Dependencies updated.

## v0.3.0 - 2021-05-17
### Added
### Changed
- Dependencies updated.
### Deleted

## v0.2.0 - 2021-05-10
### Added
### Changed
- Dependencies updated.
- Documentation edits.

### Deleted

## v0.1.1 - 2021-05-03
### Changes
- Fixed crate metadata and documentation.

## v0.1.0 - 2021-04-26
- Initial release.
